---
name: Sprint Story
about: This is a template for a sprint story.
title: ''
labels: ''
assignees: ''

---

**Effort:** 3

### Description:
As a Softie, I like code

### Tasks:
- [ ]  write code
- [ ]  ?
- [ ]  Profit


### Blockers:
- TOMToolkit/repo#issue
